Shlesha WASM Demo

# 🕉️ Shlesha Transliterator

High-performance Sanskrit and Indic script transliteration

Loading WebAssembly module...
Text to transliterate: धर्म
From script:
To script:
Show metadata (unknown tokens, conversion details)

### Try these examples:

धर्म → dharma
Devanagari to IAST
dharma → धर्म
IAST to Devanagari
धर्म → ધર્મ
Devanagari to Gujarati
dharmakr → धर्मक्र्
Mixed content with unknowns

### Supported Scripts: